<template>
  <PageLayoutWithBg class="companyDetail-page-wrapper" title="公司详情" :need-auth="false">
    <LoadingLayout :loading="isLoading" :error="isError" :loadError="refetch">
      <ContentView>
        <CompanyDesc style="background-color: #fff" :showArrow="false"></CompanyDesc>
      </ContentView>
      <ProTabs
        v-model="tab"
        name="companyDetail-tab"
        :showSmile="false"
        class="companyDetail-tabs"
        isTransparent
        title-gutter="8"
        fullHeight
      >
        <ProTabPane :title="`任务`" pane-key="1">
          <CompanyTaskList />
        </ProTabPane>
        <ProTabPane :title="`企业信息`" pane-key="2">
          <CompanyInfo />
        </ProTabPane>
      </ProTabs>
    </LoadingLayout>
  </PageLayoutWithBg>
</template>

<script setup lang="ts">
import Taro from '@tarojs/taro';
import { useQuery } from '@tanstack/vue-query';
import * as flexWorkerServices from '@12333/services/api/FlexWorker';
import CompanyDesc from '../components/CompanyDesc.vue';
import CompanyTaskList from '../components/CompanyTaskList.vue';
import CompanyInfo from '../components/CompanyInfo.vue';
import { ProTabs, ProTabPane } from '@12333/components';

defineOptions({
  name: 'companyDetail',
});

const router = Taro.useRouter();
const companyId = router.params?.id ?? '';

const tab = ref('1');

const {
  isLoading,
  isError,
  data: detail,
  refetch,
} = useQuery({
  queryKey: ['flexWorkerServices/getOrdeForDetail', companyId],
  queryFn: async () => {
    return await flexWorkerServices.getOrdeForDetail(
      { id: companyId },
      {
        showLoading: false,
      }
    );
  },
  placeholderData: () => ({} as API.OrderInfoDto),
});
</script>

<style lang="scss">
@import '@/styles/common.scss';
</style>
